@@ -1,4 +1,4 @@
-/* Copyright (C) 1999 Aaron Lehmann
+/* Copyright (C) 1999-2000 Aaron Lehmann
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -47,12 +47,10 @@
 #include "function.h"
 
 
-GdkPixmap *pixmap=NULL;
-GtkWidget **plots;
 GtkWidget *active_plot;
 GtkWidget *window1, *ctlwin, *opmenu;
 GtkWidget *layout;
-GtkWidget *canvas = NULL ;
+GtkWidget *canvas = NULL;
 GtkWidget *errlab;
 GtkWidget *edit, *entry2, *entry3, *entry4, *entry6, *entry7, *entry8, *entry9;
 GtkWidget *menu, *menu_item;
@@ -80,12 +78,10 @@ extern void get_main_menu (GtkWidget *window, GtkWidget **menubar);
 GtkWidget *
 new_layer(GtkWidget *canvas)
 {
-    nlayers++;
     
-    plots = (GtkWidget **)g_realloc(plots, nlayers * sizeof(GtkWidget *));
-    plots[nlayers-1] = gtk_plot_new_with_size(NULL, .75, .75);
+    active_plot = gtk_plot_new_with_size(NULL, .75, .75);
     
-    return plots[nlayers-1];
+    return active_plot;
 }
 
 
@@ -533,7 +529,6 @@ int main(int argc, char *argv[])
     gtk_plot_set_range (GTK_PLOT(active_plot), rangexmi, rangexma, rangeymi, rangeyma);
     gtk_plot_legends_move (GTK_PLOT(active_plot), .06, .05);
     gtk_plot_hide_legends_border (GTK_PLOT(active_plot));
-    gtk_plot_axis_hide_title (GTK_PLOT(active_plot), GTK_PLOT_AXIS_TOP);
     gtk_plot_axis_hide_title (GTK_PLOT(active_plot), GTK_PLOT_AXIS_RIGHT);
     gtk_plot_axis_show_ticks (GTK_PLOT(active_plot), 3, 15, 15);
     gtk_plot_axis_set_ticks (GTK_PLOT(active_plot), GTK_ORIENTATION_HORIZONTAL, majorticks_h, minorticks_h);
